The files in this directory contain robocop and the needed deps.

To update, erase it and run:

pip install robotframework-robocop --target .

Then:
- remove bin
- remove robot framework
- commit the code
- Verify if the license brought in from the library downloaded is OK

This folder should be automatically added to the PYTHONPATH when needed.